==> models_weebi-1.0.22.tar.gz: lib/src/extensions/tickets_iterable_fin_stats_list.dart <==
// import 'package:models_weebi/closing.dart';
// import 'package:models_weebi/reports.dart';
import 'package:models_weebi/common.dart' show FinFlow;
import 'package:models_weebi/utils.dart';
import 'package:models_weebi/weebi_models.dart';

extension FinFlowsTickets<T extends TicketWeebiAbstract> on List<T> {
  List<FinFlow> herderTkFinFlows(
      String herderId, DateRange dateRange, List<FinFlow> flows) {
    for (final ticket in this) {
      if (ticket.herderIdString == herderId && ticket.status == true) {
        if ((ticket.date.isAfter(dateRange.start) ||
                ticket.date.isAtSameMomentAs(dateRange.start)) &&
            (ticket.date.isBefore(dateRange.end) ||
                ticket.date.isAtSameMomentAs(dateRange.end))) {
          // no maintenance if financial new ticketTypes added
          if (flows.any((f) => f.type == '${ticket.ticketType}')) {
            final f = flows.firstWhere((f) => f.type == '${ticket.ticketType}');
            f.sumTickets += ticket.total;
          }
        }
      }
    }
    return flows;
  }

  List<FinFlow> shopTkFinFlows(DateRange dateRange, List<FinFlow> flows,
      {String shopUuid = ''}) {
    var ticketsFilteredById = this;
    if (shopUuid.isNotEmpty) {
      ticketsFilteredById = where((t) => t.shopId == shopUuid).toList();
    }
    ticketsFilteredById.where((t) => t.status).forEach((ticket) {
      if ((ticket.date.isAfter(dateRange.start) ||
              ticket.date.isAtSameMomentAs(dateRange.start)) &&
          (ticket.date.isBefore(dateRange.end) ||
              ticket.date.isAtSameMomentAs(dateRange.end))) {
        if (flows.any((f) => f.type == '${ticket.ticketType}')) {
          final f = flows.firstWhere((f) => f.type == '${ticket.ticketType}');

          f.sumTickets += ticket.total;
        }
      }
    });
    return flows;
  }
}

==> models_weebi-1.1.1.tar.gz: lib/src/extensions/tickets_iterable_fin_stats_list.dart <==
// import 'package:models_weebi/closing.dart';
// import 'package:models_weebi/reports.dart';
import 'package:models_weebi/common.dart' show FinFlow;
import 'package:models_weebi/utils.dart';
import 'package:models_weebi/weebi_models.dart';

extension FinFlowsTickets<T extends TicketWeebiAbstract> on List<T> {
  List<FinFlow> herderTkFinFlows(
      int herderId, DateRange dateRange, List<FinFlow> flows) {
    for (final ticket in this) {
      if (ticket.contactId == herderId && ticket.status == true) {
        if ((ticket.date.isAfter(dateRange.start) ||
                ticket.date.isAtSameMomentAs(dateRange.start)) &&
            (ticket.date.isBefore(dateRange.end) ||
                ticket.date.isAtSameMomentAs(dateRange.end))) {
          // no maintenance if financial new ticketTypes added
          if (flows.any((f) => f.type == '${ticket.ticketType}')) {
            final f = flows.firstWhere((f) => f.type == '${ticket.ticketType}');
            f.sumTickets += ticket.total;
          }
        }
      }
    }
    return flows;
  }

  List<FinFlow> shopTkFinFlows(DateRange dateRange, List<FinFlow> flows,
      {int shopId = 0}) {
    var ticketsFilteredById = this;
    //  * will only be used to filter in dashboard with multiple shops
    // if (shopId != 0) {
    //   ticketsFilteredById = where((t) => t.shopId == shopId).toList();
    // }
    ticketsFilteredById.where((t) => t.status).forEach((ticket) {
      if ((ticket.date.isAfter(dateRange.start) ||
              ticket.date.isAtSameMomentAs(dateRange.start)) &&
          (ticket.date.isBefore(dateRange.end) ||
              ticket.date.isAtSameMomentAs(dateRange.end))) {
        if (flows.any((f) => f.type == '${ticket.ticketType}')) {
          final f = flows.firstWhere((f) => f.type == '${ticket.ticketType}');

          f.sumTickets += ticket.total;
        }
      }
    });
    return flows;
  }
}
